Taurex API Documentation
========================

.. toctree::
   :maxdepth: 6

   taurex.core
   taurex.binning
   taurex.cache
   taurex.cia
   taurex.opacity
   taurex.contributions
   taurex.chemistry
   taurex.temperature
   taurex.pressure
   taurex.stellar
   taurex.instrument
   taurex.spectrum
   taurex.model
   taurex.optimizer
   taurex.log
   taurex.output
   taurex.util
   taurex.parameter
   taurex.mixin
   taurex.mpi